==> quasar-framework-0.15.3.tgz: package/icons/mdi.js <==
export default {
  name: 'mdi',
  type: {
    positive: 'mdi-check-circle',
    negative: 'mdi-alert',
    info: 'mdi-info',
    warning: 'mdi-exclamation'
  },
  arrow: {
    up: 'mdi-arrow-upward',
    right: 'mdi-arrow-forward',
    down: 'mdi-arrow-downward',
    left: 'mdi-arrow-back'
  },
  chevron: {
    left: 'mdi-chevron-left',
    right: 'mdi-chevron-right'
  },

  pullToRefresh: {
    arrow: 'mdi-arrow-downward',
    refresh: 'mdi-refresh'
  },
  search: {
    icon: 'mdi-magnify',
    clear: 'mdi-close-circle',
    clearInverted: 'mdi-close'
  },
  carousel: {
    left: 'mdi-chevron-left',
    right: 'mdi-chevron-right',
    quickNav: 'mdi-circle'
  },
  checkbox: {
    checked: {
      ios: 'mdi-checkbox-marked-circle',
      mat: 'mdi-checkbox-marked'
    },
    unchecked: {
      ios: 'mdi-checkbox-blank-circle-outline',
      mat: 'mdi-checkbox-blank-outline'
    },
    indeterminate: {
      ios: 'mdi-minus-circle-outline',
      mat: 'mdi-minus-box'
    }
  },
  chip: {
    close: 'mdi-close-circle'
  },
  chipsInput: {
    add: 'mdi-send'
  },
  collapsible: {
    icon: 'mdi-chevron-down'
  },
  datetime: {
    arrowLeft: 'mdi-chevron-left',
    arrowRight: 'mdi-chevron-right'
  },
  editor: {
    bold: 'mdi-format-bold',
    italic: 'mdi-format-italic',
    strikethrough: 'mdi-format-strikethrough-variant',
    underline: 'mdi-format-underline',
    unorderedList: 'mdi-format-list-bulleted',
    orderedList: 'mdi-format-list-numbers',
    subscript: 'mdi-format-subscript',
    superscript: 'mdi-format-superscript',
    hyperlink: 'mdi-link',
    toggleFullscreen: 'mdi-fullscreen',
    quote: 'mdi-format-quote-close',
    left: 'mdi-format-align-left',
    center: 'mdi-format-align-center',
    right: 'mdi-format-align-right',
    justify: 'mdi-format-align-justify',
    print: 'mdi-printer',
    outdent: 'mdi-format-indent-decrease',
    indent: 'mdi-format-indent-increase',
    removeFormat: 'mdi-format-clear',
    formatting: 'mdi-format-color-text',
    fontSize: 'mdi-format-size',
    align: 'mdi-format-align-left',
    hr: 'mdi-minus',
    undo: 'mdi-undo',
    redo: 'mdi-redo',
    header: 'mdi-format-size',
    code: 'mdi-code',
    size: 'mdi-format-size',
    font: 'mdi-format-font'
  },
  fab: {
    icon: 'mdi-add',
    activeIcon: 'mdi-close'
  },
  input: {
    showPass: 'mdi-eye',
    hidePass: 'mdi-eye-off',
    showNumber: 'mdi-keyboard',
    hideNumber: 'mdi-keyboard-close',
    clear: 'mdi-close-circle',
    clearInverted: 'mdi-close',
    dropdown: 'mdi-menu-down'
  },
  pagination: {
    first: 'mdi-page-first',
    prev: 'mdi-chevron-left',
    next: 'mdi-chevron-right',
    last: 'mdi-page-last'
  },
  radio: {
    checked: {
      ios: 'mdi-check',
      mat: 'mdi-radiobox-marked'
    },
    unchecked: {
      ios: '',
      mat: 'mdi-radiobox-blank'
    }
  },
  rating: {
    icon: 'mdi-star'
  },
  stepper: {
    done: 'mdi-check',
    active: 'mdi-pencil',
    error: 'mdi-alert'
  },
  tabs: {
    left: 'mdi-chevron-left',
    right: 'mdi-chevron-right'
  },
  table: {
    arrowUp: 'mdi-arrow-upward',
    warning: 'mdi-alert',
    prevPage: 'mdi-chevron-left',
    nextPage: 'mdi-chevron-right'
  },
  tree: {
    icon: 'mdi-play'
  },
  uploader: {
    done: 'mdi-done',
    clear: 'mdi-close-circle',
    clearInverted: 'mdi-close',
    add: 'mdi-plus',
    upload: 'mdi-cloud-upload',
    expand: 'mdi-chevron-down',
    file: 'mdi-file'
  }
}

==> quasar-framework-0.15.6.tgz: package/icons/mdi.js <==
export default {
  name: 'mdi',
  type: {
    positive: 'mdi-check-circle',
    negative: 'mdi-alert',
    info: 'mdi-info',
    warning: 'mdi-exclamation'
  },
  arrow: {
    up: 'mdi-arrow-up',
    right: 'mdi-arrow-right',
    down: 'mdi-arrow-down',
    left: 'mdi-arrow-left'
  },
  chevron: {
    left: 'mdi-chevron-left',
    right: 'mdi-chevron-right'
  },

  pullToRefresh: {
    arrow: 'mdi-arrow-down',
    refresh: 'mdi-refresh'
  },
  search: {
    icon: 'mdi-magnify',
    clear: 'mdi-close-circle',
    clearInverted: 'mdi-close'
  },
  carousel: {
    left: 'mdi-chevron-left',
    right: 'mdi-chevron-right',
    quickNav: 'mdi-circle'
  },
  checkbox: {
    checked: {
      ios: 'mdi-checkbox-marked-circle',
      mat: 'mdi-checkbox-marked'
    },
    unchecked: {
      ios: 'mdi-checkbox-blank-circle-outline',
      mat: 'mdi-checkbox-blank-outline'
    },
    indeterminate: {
      ios: 'mdi-minus-circle-outline',
      mat: 'mdi-minus-box'
    }
  },
  chip: {
    close: 'mdi-close-circle'
  },
  chipsInput: {
    add: 'mdi-send'
  },
  collapsible: {
    icon: 'mdi-chevron-down'
  },
  datetime: {
    arrowLeft: 'mdi-chevron-left',
    arrowRight: 'mdi-chevron-right'
  },
  editor: {
    bold: 'mdi-format-bold',
    italic: 'mdi-format-italic',
    strikethrough: 'mdi-format-strikethrough-variant',
    underline: 'mdi-format-underline',
    unorderedList: 'mdi-format-list-bulleted',
    orderedList: 'mdi-format-list-numbers',
    subscript: 'mdi-format-subscript',
    superscript: 'mdi-format-superscript',
    hyperlink: 'mdi-link',
    toggleFullscreen: 'mdi-fullscreen',
    quote: 'mdi-format-quote-close',
    left: 'mdi-format-align-left',
    center: 'mdi-format-align-center',
    right: 'mdi-format-align-right',
    justify: 'mdi-format-align-justify',
    print: 'mdi-printer',
    outdent: 'mdi-format-indent-decrease',
    indent: 'mdi-format-indent-increase',
    removeFormat: 'mdi-format-clear',
    formatting: 'mdi-format-color-text',
    fontSize: 'mdi-format-size',
    align: 'mdi-format-align-left',
    hr: 'mdi-minus',
    undo: 'mdi-undo',
    redo: 'mdi-redo',
    header: 'mdi-format-size',
    code: 'mdi-code',
    size: 'mdi-format-size',
    font: 'mdi-format-font'
  },
  fab: {
    icon: 'mdi-plus',
    activeIcon: 'mdi-close'
  },
  input: {
    showPass: 'mdi-eye',
    hidePass: 'mdi-eye-off',
    showNumber: 'mdi-keyboard',
    hideNumber: 'mdi-keyboard-close',
    clear: 'mdi-close-circle',
    clearInverted: 'mdi-close',
    dropdown: 'mdi-menu-down'
  },
  pagination: {
    first: 'mdi-page-first',
    prev: 'mdi-chevron-left',
    next: 'mdi-chevron-right',
    last: 'mdi-page-last'
  },
  radio: {
    checked: {
      ios: 'mdi-check',
      mat: 'mdi-radiobox-marked'
    },
    unchecked: {
      ios: '',
      mat: 'mdi-radiobox-blank'
    }
  },
  rating: {
    icon: 'mdi-star'
  },
  stepper: {
    done: 'mdi-check',
    active: 'mdi-pencil',
    error: 'mdi-alert'
  },
  tabs: {
    left: 'mdi-chevron-left',
    right: 'mdi-chevron-right'
  },
  table: {
    arrowUp: 'mdi-arrow-up',
    warning: 'mdi-alert',
    prevPage: 'mdi-chevron-left',
    nextPage: 'mdi-chevron-right'
  },
  tree: {
    icon: 'mdi-play'
  },
  uploader: {
    done: 'mdi-check',
    clear: 'mdi-close-circle',
    clearInverted: 'mdi-close',
    add: 'mdi-plus',
    upload: 'mdi-cloud-upload',
    expand: 'mdi-chevron-down',
    file: 'mdi-file'
  }
}
